@@ -1,3 +1,4 @@
+import numpy as np
 from eloquentarduino.ml.data.preprocessing.BaseStep import BaseStep
 
 
@@ -5,7 +6,7 @@ class NormalizeStep(BaseStep):
     """Apply min/max normalization"""
     def __init__(self, X, y, featurewise=False):
         BaseStep.__init__(self, X, y)
-        self.featurewise = featurewise
+        self.featurewise = int(featurewise)
         self.min = None
         self.max = None
 
@@ -17,9 +18,17 @@ class NormalizeStep(BaseStep):
         return self.describe(('featurewise', self.featurewise))
 
     def transform(self):
-        axis = 0 if self.featurewise else None
-        self.min = self.X.min(axis)
-        self.max = self.X.max(axis)
+        if not self.featurewise:
+            self.min = self.X.min()
+            self.max = self.X.max()
+        elif self.featurewise == 1:
+            self.min = self.X.min(axis=0)
+            self.max = self.X.max(axis=0)
+        else:
+            mins = [self.X[:, i::self.featurewise].min() for i in range(self.featurewise)]
+            maxs = [self.X[:, i::self.featurewise].max() for i in range(self.featurewise)]
+            self.min = np.asarray(mins * (self.input_dim // self.featurewise))
+            self.max = np.asarray(maxs * (self.input_dim // self.featurewise))
         return self.apply((self.X - self.min) / (self.max - self.min))
 
     def port(self):
